@@ -10,6 +10,7 @@ require "rabbit/theme/manager"
 require "rabbit/front"
 require "rabbit/action"
 require "rabbit/html/generator"
+require "rabbit/twitter"
 
 module Rabbit
   class Canvas
@@ -89,11 +90,6 @@ module Rabbit
     def_delegators(:@renderer, :whiteouting?, :blackouting?)
     def_delegators(:@renderer, :toggle_whiteout, :toggle_blackout)
 
-    def_delegators(:@renderer, :showing_comment_frame?, :showing_comment_view?)
-    def_delegators(:@renderer, :toggle_comment_frame, :toggle_comment_view)
-    def_delegators(:@renderer, :comment_frame_available?)
-    def_delegators(:@renderer, :comment_view_available?)
-
     def_delegators(:@renderer, :adjustment_x, :adjustment_x=)
     def_delegators(:@renderer, :adjustment_y, :adjustment_y=)
     def_delegators(:@renderer, :reset_adjustment)
@@ -123,18 +119,19 @@ module Rabbit
     def_delegators(:@source, :source=, :reset, :base)
 
     attr_reader :logger, :renderer, :last_modified
-    attr_reader :comment_source, :actions
+    attr_reader :comments, :actions
     
     attr_writer :saved_image_base_name
-    attr_writer :use_gl
+    attr_writer :use_gl, :allotted_time
 
     attr_accessor :saved_image_type, :rss_base_uri
     attr_accessor :output_html, :output_index_html
     attr_accessor :source_filename
     attr_accessor :migemo_dictionary_search_path, :migemo_dictionary_name
     attr_accessor :font_resolution_ratio
+    attr_accessor :max_n_comments, :comment_theme
 
-    def initialize(logger, renderer, comment_source=nil, comment_encoding=nil)
+    def initialize(logger, renderer)
       @logger = logger
       @frame = NullFrame.new
       @theme_name = nil
@@ -153,7 +150,10 @@ module Rabbit
       @limit_time = nil
       @use_gl = false
       @font_resolution_ratio = 1
-      init_comment(comment_source, comment_encoding)
+      @twitter = nil
+      @max_n_comments = 100
+      @allotted_time = nil
+      @comment_theme = nil
       clear
       @renderer = renderer.new(self)
       @actions = Action.action_group(self)
@@ -176,6 +176,7 @@ module Rabbit
     end
 
     def quit
+      clear_twitter
       @quitted = true
       @frame.quit
     end
@@ -564,30 +565,29 @@ module Rabbit
       end
     end
 
+    def on_comment(name, &callback)
+      @on_comment_callbacks << [name, callback]
+    end
+
+    def delete_on_comment_proc_by_name(name)
+      @on_comment_callbacks.reject! do |callback_name, callback|
+        callback_name == name
+      end
+    end
+
     def append_comment(comment)
-      comment = prepare_comment(comment)
-      comment = "\n= #{comment}" if /\A\s*\z/ !~ comment
-      prev_source = @comment_source.read
-      @comment_source.source = "#{prev_source}#{comment}"
-      @renderer.update_comment(@comment_source) do |error|
-        @comment_source.source = prev_source
-        if block_given?
-          yield(error)
-        else
-          logger.warn(error)
+      @comments << comment
+      @comments.shift if @comments.size > @max_n_comments
+      @on_comment_callbacks.each do |name, callback|
+        begin
+          callback.call(comment)
+        rescue
+          logger.error($!)
         end
-        return false
       end
       true
     end
 
-    def comments
-      comments = @comment_source.read.split(/^=\s*(?=[^=]+$)/)[2..-1]
-      comments.collect do |comment|
-        comment.strip
-      end
-    end
-    
     def title_slide
       @slides.find{|x| x.is_a?(Element::TitleSlide)}
     end
@@ -622,8 +622,9 @@ module Rabbit
     end
 
     def allotted_time
-      slide = title_slide
-      slide ? slide.allotted_time : nil
+      time = @allotted_time
+      time ||= title_slide.allotted_time if title_slide
+      Utils.ensure_time(time)
     end
 
     def start_timer(limit)
@@ -642,6 +643,10 @@ module Rabbit
       INTERNAL_DPI * @font_resolution_ratio
     end
 
+    def twitter
+      @twitter ||= Twitter.new(@logger)
+    end
+
     private
     def _apply_theme(name, id, &block)
       @theme_name = name if name
@@ -692,13 +697,26 @@ module Rabbit
     end
     
     def clear
+      clear_twitter
+      clear_comments
       reset_timer
       stop_auto_redraw_timer
       clear_slides
       clear_index_slides
       modified
     end
-    
+
+    def clear_twitter
+      return if @twitter.nil?
+      @twitter.close
+      @twitter = nil
+    end
+
+    def clear_comments
+      @comments = []
+      @on_comment_callbacks = []
+    end
+
     def clear_slides
       @current_index = 0
       @slides = []
@@ -748,24 +766,5 @@ module Rabbit
       Action.update_status(self)
       @renderer.post_move(old_index, current_index)
     end
-
-    def init_comment(comment_source, comment_encoding)
-      args = [comment_encoding, logger, comment_source]
-      @comment_source = Source::Memory.new(*args)
-      if /^=\s*[^=]+$/ !~ @comment_source.read
-        @comment_source.source = default_comment_source
-      end
-    end
-
-    def default_comment_source
-      source = "= " + _("Comment") + "\n"
-      source << ": theme\n"
-      source << "   comment\n"
-      source
-    end
-
-    def prepare_comment(comment)
-      comment.to_s.gsub(/\r?\n/, '')
-    end
   end
 end
