@@ -238,15 +238,15 @@ module Rabbit
       end
 
       def draw_layout(canvas, x, y)
-        shadow_color = self["shadow-color"]
+        shadow_color = prop_value("shadow-color")
         if shadow_color
           shadow_foreground = Format::Foreground.new(shadow_color)
           shadow_text = markup(shadow_foreground.format(text))
           shadow_layout = canvas.make_layout(shadow_text)
           setup_layout(shadow_layout, @layout.width / Pango::SCALE)
           line_height = shadow_layout.pixel_size[1] / shadow_layout.line_count
-          shadow_x = self["shadow-x"] || (line_height * 0.08)
-          shadow_y = self["shadow-y"] || (line_height * 0.06)
+          shadow_x = prop_value("shadow-x") || (line_height * 0.08)
+          shadow_y = prop_value("shadow-y") || (line_height * 0.06)
           canvas.draw_layout(shadow_layout, x + shadow_x, y + shadow_y,
                              shadow_color)
         end
