@@ -59,11 +59,12 @@ module Rabbit
           mode = :ignore
           contents.each do |content|
             case content
+            when :no_element
+              next
             when nil
               mode = :ignore
             when Slide
-              target = Body.new
-              content << target
+              target = content.body
               @canvas << content
               mode = :display
             when TitleSlide
@@ -95,6 +96,7 @@ module Rabbit
               @slide = TitleSlide.new(Title.new(title))
             else
               @slide = Slide.new(HeadLine.new(title))
+              @slide << Body.new
             end
             @foot_texts << []
             @slides << @slide
@@ -277,6 +279,10 @@ module Rabbit
           klass.new(content.collect{|x| x.text}.join(""))
         end
 
+        def current_body
+          @slide.body
+        end
+
         private
         def prepare_footnotes(tree)
           @footnotes = tree.find_all{|i| i.is_a? ::RD::Footnote}
