@@ -1,19 +1,25 @@
-begin
-  require "hikidoc"
-rescue LoadError
-  require "rubygems"
-  require "hikidoc"
-end
+require "hikidoc"
 
 require "rabbit/parser/base"
 
 module Rabbit
   module Parser
     class Wiki < Base
+    end
+  end
+end
+
+require "rabbit/parser/wiki/output"
+
+module Rabbit
+  module Parser
+    class Wiki
       unshift_loader(self)
       class << self
         def match?(source)
-          /^!/.match(source.read[0, 500])
+          head = source.read[0, 500]
+          head.force_encoding("ASCII-8BIT") if head.respond_to?(:force_encoding)
+          /^!/.match(head)
         end
       end
 
@@ -26,5 +32,3 @@ module Rabbit
     end
   end
 end
-
-require "rabbit/parser/wiki/output"
