@@ -167,7 +167,7 @@ module Rabbit
           x2, y2 = from_screen(x2, y2)
           @context.save do
             set_source(color, params)
-            set_line_width(get_line_width(params))
+            set_line_options(params)
             @context.new_path
             @context.move_to(x1, y1)
             @context.line_to(x2, y2)
@@ -179,7 +179,7 @@ module Rabbit
           x, y = from_screen(x, y)
           @context.save do
             set_source(color, params)
-            set_line_width(get_line_width(params))
+            set_line_options(params)
             @context.rectangle(x, y, w, h)
             apply_cairo_action(filled, params)
           end
@@ -193,7 +193,7 @@ module Rabbit
 
           @context.save do
             set_source(color, params)
-            set_line_width(get_line_width(params))
+            set_line_options(params)
             @context.new_path
             @context.rounded_rectangle(x, y, w, h, x_radius, y_radius)
             apply_cairo_action(filled, params)
@@ -211,7 +211,7 @@ module Rabbit
           a1, a2 = convert_angle(a1, a2)
           @context.save do
             set_source(color, params)
-            set_line_width(get_line_width(params))
+            set_line_options(params)
             args = [x, y, r, a1, a2]
             action, = cairo_action(filled, params)
             @context.move_to(x, y) unless action == :stroke
@@ -229,7 +229,7 @@ module Rabbit
           return if points.empty?
           @context.save do
             set_source(color, params)
-            set_line_width(get_line_width(params))
+            set_line_options(params)
             @context.move_to(*from_screen(*points.first))
             points[1..-1].each do |x, y|
               @context.line_to(*from_screen(x, y))
@@ -243,7 +243,7 @@ module Rabbit
           x, y = from_screen(x, y)
           @context.save do
             set_source(color, params)
-            set_line_width(get_line_width(params))
+            set_line_options(params)
             @context.move_to(x, y)
             @context.show_pango_layout(layout)
           end
@@ -368,11 +368,30 @@ module Rabbit
             info[:color_stops].each do |offset, r, g, b, a|
               pattern.add_color_stop_rgba(offset, r, g, b, a)
             end
+          when :pixbuf
+            @context.set_source_pixbuf(info[:pixbuf])
+            pattern = @context.source
+          end
+          if pattern
+            set_pattern_common_options(pattern, info)
+            @context.set_source(pattern)
           end
-          @context.set_source(pattern) if pattern
           !pattern.nil?
         end
 
+        def set_pattern_common_options(pattern, info)
+          extend = info[:extend]
+          pattern.extend = extend if extend
+          transformations = info[:transformations]
+          if transformations
+            matrix = ::Cairo::Matrix.identity
+            transformations.each do |operation, *args|
+              matrix.send("#{operation}!", *args)
+            end
+            pattern.matrix = matrix
+          end
+        end
+
         def set_color(color)
           @context.set_source_rgba(make_color(color).to_a)
         end
@@ -437,6 +456,14 @@ module Rabbit
             @context.mask(pattern)
           end
         end
+
+        def set_line_options(params)
+          set_line_width(get_line_width(params))
+          [:line_cap, :line_join].each do |key|
+            value = params[key]
+            @context.send("#{key}=", value) if value
+          end
+        end
       end
     end
   end
