@@ -1,4 +1,5 @@
 require 'fileutils'
+require 'tmpdir'
 
 require 'rabbit/rabbit'
 
@@ -109,6 +110,9 @@ module Rabbit
         else
           @tmp_base = "."
         end
+        unless ::File.writable?(@tmp_base)
+          @tmp_base = Dir.tmpdir
+        end
       end
 
       def parse_uri(str)
