@@ -1,5 +1,6 @@
-@default_foreground ||= "black"
-@default_background ||= "white"
+@default_foreground ||= @foreground
+@default_background ||= @background
+@default_shadow_color ||= @shadow_color
 
 set_foreground(@default_foreground)
 set_background(@default_background)
@@ -28,3 +29,7 @@ include_theme("per-slide-background-image")
 include_theme("body-background-image")
 
 include_theme("tag")
+
+include_theme("syntax-highlighting")
+
+include_theme("default-comment")
