@@ -146,6 +146,32 @@ module Rabbit
       /cygwin|mingw|mswin32|bccwin32/.match(RUBY_PLATFORM) ? true : false
     end
 
+    def support_console_input?
+      if windows?
+        begin
+          File.open("conin$", "w") {}
+          true
+        rescue SystemCallError
+          false
+        end
+      else
+        $stdin.tty? or ENV["TERM"]
+      end
+    end
+
+    def support_console_output?
+      if windows?
+        begin
+          File.open("conout$", "w") {}
+          true
+        rescue SystemCallError
+          false
+        end
+      else
+        $stdout.tty? or ENV["TERM"]
+      end
+    end
+
     def quartz?
       if Gdk.respond_to?(:windowing_quartz?)
         Gdk.windowing_quartz?
@@ -230,7 +256,7 @@ module Rabbit
     end
 
     def parse_four_way(*values)
-      if values.is_a?(Array) and values.size == 1 and
+      if values.size == 1 and
           (values.first.is_a?(Array) or values.first.is_a?(Hash))
         values = values.first
       end
@@ -241,14 +267,14 @@ module Rabbit
         when 1
           left = right = top = bottom = Integer(values.first)
         when 2
-          top, left = values.collect{|x| Integer(x)}
+          top, left = values.collect {|x| Integer(x)}
           bottom = top
           right = left
         when 3
-          top, left, bottom = values.collect{|x| Integer(x)}
+          top, left, bottom = values.collect {|x| Integer(x)}
           right = left
         when 4
-          top, right, bottom, left = values.collect{|x| Integer(x)}
+          top, right, bottom, left = values.collect {|x| Integer(x)}
         else
           raise ArgumentError
         end
@@ -256,6 +282,31 @@ module Rabbit
       end
     end
 
+    def ensure_time(object)
+      return nil if object.nil?
+      return object if object.is_a?(Numeric)
+
+      if /\A\s*\z/m =~ object
+        nil
+      else
+        if /\A\s*(\d*\.?\d*)\s*(h|m|s)?\s*\z/i =~ object
+          time = $1.to_f
+          unit = $2
+          if unit
+            case unit.downcase
+            when "m"
+              time *= 60
+            when "h"
+              time *= 3600
+            end
+          end
+          time.to_i
+        else
+          nil
+        end
+      end
+    end
+
     def split_number_to_minute_and_second(number)
       if number >= 0
         sign = " "
@@ -274,13 +325,16 @@ module Rabbit
       p output
     end
 
-    def stringify_hash_key!(hash)
-      dupped_hash = hash.dup
-      hash.clear
-      dupped_hash.each do |key, value|
-        hash[key.to_s] = value
+    def stringify_hash_key(hash)
+      stringified_hash = {}
+      hash.each do |key, value|
+        stringified_hash[key.to_s] = value
       end
-      hash
+      stringified_hash
+    end
+
+    def syntax_highlighting_debug?
+      ENV["RABBIT_SYNTAX_HIGHLIGHTING_DEBUG"] == "yes"
     end
   end
 
